pub enum TextAlign {
Start,
Center,
End,
Left,
Right,
}Expand description
Horizontal alignment for a cue / a style row.
Variants
Start
Aligned to the text-direction start edge (left in left-to-right scripts). WebVTT default.
Center
Centered.
End
Aligned to the text-direction end edge (right in left-to-right scripts).
Left
Aligned to the left edge regardless of text direction.
Right
Aligned to the right edge regardless of text direction.