pub struct Path {
pub commands: Vec<PathCommand>,
}Expand description
A geometric path expressed as a sequence of drawing commands.
All coordinates are in the local user space of the enclosing group.
Fields
commands: Vec<PathCommand>Drawing commands, executed in order.
Implementations
Sourceimpl Path
impl Path
Sourcepub fn move_to(&mut self, p: Point) -> &mut Self
pub fn move_to(&mut self, p: Point) -> &mut Self
Append a PathCommand::MoveTo — start a new subpath at p.
Sourcepub fn line_to(&mut self, p: Point) -> &mut Self
pub fn line_to(&mut self, p: Point) -> &mut Self
Append a PathCommand::LineTo — straight line to p.
Sourcepub fn quad_to(&mut self, control: Point, end: Point) -> &mut Self
pub fn quad_to(&mut self, control: Point, end: Point) -> &mut Self
Append a PathCommand::QuadCurveTo — quadratic Bezier to end
with control point control.
Sourcepub fn cubic_to(&mut self, c1: Point, c2: Point, end: Point) -> &mut Self
pub fn cubic_to(&mut self, c1: Point, c2: Point, end: Point) -> &mut Self
Append a PathCommand::CubicCurveTo — cubic Bezier to end
with control points c1 and c2.
Sourcepub fn close(&mut self) -> &mut Self
pub fn close(&mut self) -> &mut Self
Append a PathCommand::Close — close the current subpath.