TimeBase

Struct TimeBase 

pub struct TimeBase(pub Rational);
A time base expressed as a rational number of seconds per tick.

A TimeBase of 1/48000 means each timestamp unit is 1/48000 second.

Tuple Fields

0: Rational

Implementations

Source

impl TimeBase

pub const fn new(num: i64, den: i64) -> Self

pub fn as_rational(&self) -> Rational

pub fn seconds_of(&self, ticks: i64) -> f64

Convert a tick count in this time base to seconds.

pub fn rescale(&self, ts: i64, target: TimeBase) -> i64

Rescale a timestamp from this time base to another.