pub struct Path {
pub commands: Vec<PathCommand>,
}Expand description
A geometric path expressed as a sequence of drawing commands.
All coordinates are in the local user space of the enclosing group.
Fields
commands: Vec<PathCommand>Implementations
Sourceimpl Path
impl Path
pub fn new() -> Self
pub fn move_to(&mut self, p: Point) -> &mut Self
pub fn line_to(&mut self, p: Point) -> &mut Self
pub fn quad_to(&mut self, control: Point, end: Point) -> &mut Self
pub fn cubic_to(&mut self, c1: Point, c2: Point, end: Point) -> &mut Self
pub fn close(&mut self) -> &mut Self